/***************************************************************************
                          sambaoption.cpp  -  description
                             -------------------
    begin                : Tue Jan  7 15:33:56 CET 2003
    copyright            : (C) 2003 by Jan Schfer
    email                : janschaefer@users.sourceforge.net
 ***************************************************************************/

/******************************************************************************
 *                                                                            *
 *  This file is part of KSambaPlugin.                                        * 
 *                                                                            *
 *  KSambaPlugin is free software; you can redistribute it and/or modify      *
 *  it under the terms of the GNU General Public License as published by      *
 *  the Free Software Foundation; either version 2 of the License, or         *
 *  (at your option) any later version.                                       *
 *                                                                            *
 *  KSambaPlugin is distributed in the hope that it will be useful,           *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *  GNU General Public License for more details.                              *
 *                                                                            *
 *  You should have received a copy of the GNU General Public License         *
 *  along with KSambaPlugin; if not, write to the Free Software                     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA  *
 *                                                                            *
 ******************************************************************************/

#include <assert.h> 
 
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qlabel.h>
#include <qspinbox.h>
#include <qlayout.h>
#include <qtoolbutton.h>
#include <qtooltip.h>

#include <kurlrequester.h>
#include <kiconloader.h>
#include <kapplication.h>
#include <klocale.h>

#include "sambashare.h"
#include "sambaoption.h"

#include "designerplugin/images.cpp"

SambaOption::SambaOption( QWidget *parent, const char *name) 
  : QWidget(parent,name) 
{
   _layout = new QHBoxLayout( this );
   _layout->setMargin( 0 );

   _defaultBtn = new QToolButton( this );
   _defaultBtn->setFixedSize(16,16);
   QToolTip::add(_defaultBtn, i18n("Reset to default value"));
   _warningPix = new QLabel( this );
   
   if (kapp)
    _defaultBtn->setIconSet(SmallIcon("reload"));
   
  _layout->addSpacing(5);
  _layout->add(_defaultBtn);
  _layout->addSpacing(5);
  _layout->add(_warningPix);    
  _layout->addStretch(100);

  _warningPix->setScaledContents(true);
  _warningPix->setFixedSize(16,16);
  
  updateWarning();
  
  connect( _defaultBtn, SIGNAL(clicked()), this, SLOT(setToDefault()));
}

void SambaOption::updateWarning() {
}

void SambaOption::setSambaShare( SambaShare* share ) {
  _sambaShare = share;
}

SambaShare* SambaOption::sambaShare() const {
  return _sambaShare;
}

SambaOption::WarningKind SambaOption::warningKind() const {
  return _warningKind;
}

QString SambaOption::warningString() const {
  return _warningString;
}

QString SambaOption::sambaOption() const {
  return _sambaOption;
}

void SambaOption::showWarning(bool b) {

  if ( !b || warningKind() == None)
    _warningPix->hide();
  else {
    // This must be done because the Designer Plugin crashes otherwise
    if (kapp) {
      switch ( _warningKind ) {
        case Warning : _warningPix->setPixmap(SmallIcon("messagebox_warning")); break;
        case Information : _warningPix->setPixmap(SmallIcon("messagebox_information"));break;
        case Critical : _warningPix->setPixmap(SmallIcon("messagebox_critical"));break;
        default : break;
      }
    }
    _warningPix->show();
    emit warning(warningString());
 }
}


void SambaOption::setWarningKind( WarningKind w) {
  _warningKind = w;
  
}

void SambaOption::setWarningString( const QString & s) {
  _warningString = s;
  QToolTip::add(_warningPix,s);
}

void SambaOption::setSambaOption( const QString & s) {
  _sambaOption = s;
}

bool SambaOption::isGlobalOption() const {
  return _isGlobalOption;
}

void SambaOption::setGlobalOption(bool b) {
  _isGlobalOption = b;
}

void SambaOption::setToDefault() {
  assert( _sambaShare );
  
  QString defaultValue =  _sambaShare->getDefaultValue(_sambaOption);
  _sambaShare->setValue( _sambaOption, defaultValue);
  load();
}


SambaOptionCheckBox::SambaOptionCheckBox( QWidget *parent, const char *name) 
  : SambaOption(parent,name) 
{
   
   _checkBox = new QCheckBox( this );
   
   _layout->insertWidget(0, _checkBox );
   
   connect( _checkBox, SIGNAL(clicked()), this, SLOT(changedSlot()));
}

void SambaOptionCheckBox::setLabel(const QString & s) {
  _checkBox->setText(s);
}

QString SambaOptionCheckBox::label() const{ 
  return _checkBox->text();
}

void SambaOptionCheckBox::load() {
  assert( _sambaShare );

  _checkBox->setChecked( _sambaShare->getBoolValue( _sambaOption, ! isGlobalOption()));
}

void SambaOptionCheckBox::save() {
  assert( _sambaShare );

  _sambaShare->setValue( _sambaOption, _checkBox->isChecked(), ! isGlobalOption());
}

void SambaOptionCheckBox::setWarningEvent( WarningEvent warningEvent ) {
  _warningEvent = warningEvent; 
}
 
SambaOptionCheckBox::WarningEvent SambaOptionCheckBox::warningEvent() const {
  return _warningEvent;
}


void SambaOptionCheckBox::changedSlot() {
  updateWarning();
      
  emit changed();
}

void SambaOptionCheckBox::updateWarning() {
  bool b = _checkBox->isChecked();
  
  if ( (b && warningEvent() == isChecked) ||
       (!b && warningEvent() == isNotChecked))
  {       
  
    showWarning(true);  
  } else
    showWarning(false);
}

#include "sambaoption.moc"
